@@ -38,6 +38,8 @@ class Hardware(PolymorphicModel):
         PiPico = 'PiPico'
         Pi = 'Pi'
         VEML7700 = 'VEML7700'
+        PMSA0031 = 'PMSA0031'
+        AM2315 = 'AM2315'
 
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
     type = models.CharField(
